# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.4] - 2023-08-09
### Added
- Method `setenv` to set an environment variable

## [1.0.2] - 2021-05-27
### Changed
- Fix check of an empty but required environment variable

## [1.0.1] - 2021-05-26
### Added
- Add parameter `env_path_file_name` to specify the absolute or relative path to .env file.

## [1.0.0] - 2021-05-26
### Added
- Initial import